@@ -19,7 +19,6 @@ from unittest import mock
 import warnings
 
 from oslotest import base as test_base
-import six
 import testtools
 
 from oslo_i18n import _message
@@ -42,13 +41,13 @@ class MessageTestCase(test_base.BaseTestCase):
 
     def test_message_is_unicode(self):
         message = _message.Message('some %s') % 'message'
-        self.assertIsInstance(message, six.text_type)
+        self.assertIsInstance(message, str)
 
-    @mock.patch('locale.getdefaultlocale')
+    @mock.patch('locale.getlocale')
     @mock.patch('gettext.translation')
     def test_create_message_non_english_default_locale(self,
                                                        mock_translation,
-                                                       mock_getdefaultlocale):
+                                                       mock_locale):
         msgid = 'A message in English'
         es_translation = 'A message in Spanish'
 
@@ -56,7 +55,7 @@ class MessageTestCase(test_base.BaseTestCase):
         translations_map = {'es': es_translations}
         translator = fakes.FakeTranslations.translator(translations_map)
         mock_translation.side_effect = translator
-        mock_getdefaultlocale.return_value = ('es',)
+        mock_locale.return_value = ('es',)
 
         message = _message.Message(msgid)
 
@@ -67,7 +66,7 @@ class MessageTestCase(test_base.BaseTestCase):
 
     def test_translation_returns_unicode(self):
         message = _message.Message('some %s') % 'message'
-        self.assertIsInstance(message.translation(), six.text_type)
+        self.assertIsInstance(message.translation(), str)
 
     def test_mod_with_named_parameters(self):
         msgid = ("%(description)s\nCommand: %(cmd)s\n"
@@ -167,11 +166,8 @@ class MessageTestCase(test_base.BaseTestCase):
             result = _message.Message(msgid) % params
             # Now set up ugettext to return the translated version of
             # the original message, with a bad format string.
-            wrong_type = u'Wrong type %(arg1)d'
-            if six.PY3:
-                trans.return_value.gettext.return_value = wrong_type
-            else:
-                trans.return_value.ugettext.return_value = wrong_type
+            wrong_type = 'Wrong type %(arg1)d'
+            trans.return_value.gettext.return_value = wrong_type
             trans_result = result.translation()
             expected = msgid % params
             self.assertEqual(expected, trans_result)
@@ -327,7 +323,7 @@ class MessageTestCase(test_base.BaseTestCase):
         # Here we are not testing the Message object directly but the result
         # of unicoding() an object whose unicode representation is a Message
         obj = utils.SomeObject(message)
-        unicoded_obj = six.text_type(obj)
+        unicoded_obj = str(obj)
 
         self.assertEqual(es_translation, unicoded_obj.translation('es'))
 
@@ -384,6 +380,7 @@ class MessageTestCase(test_base.BaseTestCase):
 
         with warnings.catch_warnings(record=True) as w:
             warnings.simplefilter("always")
+            warnings.filterwarnings("ignore", category=DeprecationWarning)
             msg = _message.Message(message_with_params)
             msg = msg % param
             default_translation = message_with_params % param
@@ -408,11 +405,11 @@ class MessageTestCase(test_base.BaseTestCase):
                                           mock.ANY)
 
     @mock.patch('gettext.translation')
-    @mock.patch('locale.getdefaultlocale', return_value=('es', ''))
+    @mock.patch('locale.getlocale', return_value=('es', ''))
     @mock.patch('oslo_i18n._message.LOG')
     def test_translate_message_bad_default_translation(self,
                                                        mock_log,
-                                                       mock_local,
+                                                       mock_locale,
                                                        mock_translation):
         message_with_params = 'A message: %s'
         es_translation = 'A message in Spanish: %s %s'
@@ -494,7 +491,7 @@ class MessageTestCase(test_base.BaseTestCase):
         expected_translation = es_translation % param
 
         obj = utils.SomeObject(msg)
-        unicoded_obj = six.text_type(obj)
+        unicoded_obj = str(obj)
 
         self.assertEqual(expected_translation, unicoded_obj.translation('es'))
         self.assertEqual(default_translation, unicoded_obj.translation('XX'))
@@ -568,11 +565,11 @@ class MessageTestCase(test_base.BaseTestCase):
         self.assertEqual(expected_translation, msg.translation('es'))
         self.assertEqual(default_translation, msg.translation('XX'))
 
-    @mock.patch('locale.getdefaultlocale')
+    @mock.patch('locale.getlocale')
     @mock.patch('gettext.translation')
     def test_translate_message_non_default_locale(self,
                                                   mock_translation,
-                                                  mock_getdefaultlocale):
+                                                  mock_locale):
         message_with_params = 'A message with params: %(param)s'
         es_translation = 'A message with params in Spanish: %(param)s'
         zh_translation = 'A message with params in Chinese: %(param)s'
@@ -594,7 +591,7 @@ class MessageTestCase(test_base.BaseTestCase):
                                                         'zh': zh_translations,
                                                         'fr': fr_translations})
         mock_translation.side_effect = translator
-        mock_getdefaultlocale.return_value = ('es',)
+        mock_locale.return_value = ('es',)
 
         msg = _message.Message(message_with_params)
         msg_param = _message.Message(message_param)
@@ -604,7 +601,7 @@ class MessageTestCase(test_base.BaseTestCase):
         zh_translation = zh_translation % {'param': zh_param_translation}
         fr_translation = fr_translation % {'param': fr_param_translation}
 
-        # Because sys.getdefaultlocale() was Spanish,
+        # Because sys.getlocale() was Spanish,
         # the default translation will be to Spanish
         self.assertEqual(es_translation, msg)
         self.assertEqual(es_translation, msg.translation())
